

Composed PDFs build on top of others and provide sums, products and more.

.. autosummary::
    :toctree: _generated/composed_pdf

    zfit.pdf.ProductPDF
    zfit.pdf.SumPDF
    zfit.pdf.FFTConvPDFV1
    zfit.pdf.ConditionalPDFV1
